@@ -1,13 +1,6 @@
 import lcdata
 
 
-def test_generate_object_id():
-    object_id_1 = lcdata.utils.generate_object_id()
-    object_id_2 = lcdata.utils.generate_object_id()
-
-    assert object_id_1 != object_id_2
-
-
 def test_warn_first_time(capsys):
     lcdata.utils.warn_first_time('key1', 'Warning 1')
     captured = capsys.readouterr()
